WITH data AS (
  SELECT wp.id,
         ST_GeometryN(wp.geom,1) as line,
         ns.node_point as point
    FROM public.network_stops as ns
         INNER JOIN public.network as wp
            ON ST_DWithin(wp.geom,ns.node_point,0.01)
)
, ShortLines as (
SELECT id, 
       shortened_line, 
       short_line
  FROM (SELECT id,
               shortened_line, 
               CASE WHEN startEndType = 'START'
                    THEN ST_MakeLine(point,ST_StartPoint(shortened_line))
                    ELSE ST_MakeLine(ST_EndPoint(shortened_line),point)
                END as short_line
          FROM (SELECT id,
                       point, 
                       CASE WHEN ST_Equals(ST_StartPoint(line),point) 
                            THEN 'START'
                            ELSE 'END'
                        END as startEndType,
                       ST_GeometryN(
                            CASE WHEN ST_Equals(ST_StartPoint(line),point) 
                                 THEN spdba.ST_Reduce(line,0.05,'START',3,2) 
                                 ELSE spdba.ST_Reduce(line,0.05,'END',3,2)
                             END,
                            1
                       ) as shortened_line
                  FROM data as a
               ) as f
       ) as g
 WHERE ROUND(ST_LENGTH(short_line)::numeric,3) < 0.055
)
/*
-- Insert new short_lines with their attributes...
INSERT INTO public.network (
  source, target, cost, reverse_cost, material, diameter, pipeclass, zone_name, measured_length, geom
)
SELECT nw.source, nw.target, 
       -1 as cost, /* stop routing */
       -1 as reverse_cost, 
       nw.material, nw.diameter, nw.pipeclass, nw.zone_name,
       ROUND(ST_Length(a.short_line)::numeric,3) as measured_length, 
       ST_Multi(a.short_line)
  FROM ShortLines as a
        inner join 
          public.network as nw
            on (nw.id = a.id);
*/
-- Now update existing lines with their shortened equivalent
UPDATE public.network 
   SET geom = ST_Multi(ShortLines.shortened_line) 
  FROM (SELECT distinct id, shortened_line FROM ShortLines as s) as ShortLines
 WHERE network.id = ShortLines.id;
-- 56 Lines Updated

select count(*) FROM public.network;
